==> huaweicloudsdkddm-3.0.52-py2.py3-none-any.whl: huaweicloudsdkddm/v1/model/create_instance_req.py <==
# coding: utf-8

import re
import six





class CreateInstanceReq:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'instance': 'CreateInstanceDetail',
        'extend_param': 'CreateInstanceExtendParam'
    }

    attribute_map = {
        'instance': 'instance',
        'extend_param': 'extend_param'
    }

    def __init__(self, instance=None, extend_param=None):
        """CreateInstanceReq - a model defined in huaweicloud sdk"""
        
        

        self._instance = None
        self._extend_param = None
        self.discriminator = None

        self.instance = instance
        if extend_param is not None:
            self.extend_param = extend_param

    @property
    def instance(self):
        """Gets the instance of this CreateInstanceReq.


        :return: The instance of this CreateInstanceReq.
        :rtype: CreateInstanceDetail
        """
        return self._instance

    @instance.setter
    def instance(self, instance):
        """Sets the instance of this CreateInstanceReq.


        :param instance: The instance of this CreateInstanceReq.
        :type: CreateInstanceDetail
        """
        self._instance = instance

    @property
    def extend_param(self):
        """Gets the extend_param of this CreateInstanceReq.


        :return: The extend_param of this CreateInstanceReq.
        :rtype: CreateInstanceExtendParam
        """
        return self._extend_param

    @extend_param.setter
    def extend_param(self, extend_param):
        """Sets the extend_param of this CreateInstanceReq.


        :param extend_param: The extend_param of this CreateInstanceReq.
        :type: CreateInstanceExtendParam
        """
        self._extend_param = extend_param

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateInstanceReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkddm-3.0.53-py2.py3-none-any.whl: huaweicloudsdkddm/v1/model/create_instance_req.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateInstanceReq:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'instance': 'CreateInstanceDetail',
        'extend_param': 'CreateInstanceExtendParam'
    }

    attribute_map = {
        'instance': 'instance',
        'extend_param': 'extend_param'
    }

    def __init__(self, instance=None, extend_param=None):
        """CreateInstanceReq - a model defined in huaweicloud sdk"""
        
        

        self._instance = None
        self._extend_param = None
        self.discriminator = None

        self.instance = instance
        if extend_param is not None:
            self.extend_param = extend_param

    @property
    def instance(self):
        """Gets the instance of this CreateInstanceReq.


        :return: The instance of this CreateInstanceReq.
        :rtype: CreateInstanceDetail
        """
        return self._instance

    @instance.setter
    def instance(self, instance):
        """Sets the instance of this CreateInstanceReq.


        :param instance: The instance of this CreateInstanceReq.
        :type: CreateInstanceDetail
        """
        self._instance = instance

    @property
    def extend_param(self):
        """Gets the extend_param of this CreateInstanceReq.


        :return: The extend_param of this CreateInstanceReq.
        :rtype: CreateInstanceExtendParam
        """
        return self._extend_param

    @extend_param.setter
    def extend_param(self, extend_param):
        """Sets the extend_param of this CreateInstanceReq.


        :param extend_param: The extend_param of this CreateInstanceReq.
        :type: CreateInstanceExtendParam
        """
        self._extend_param = extend_param

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateInstanceReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
